# Discovering AI Agents from Microsoft Entra ID
### On this page
  * [Overview](https://help.sap.com/docs/leanix/ea/discovering-ai-agents-from-microsoft-entra-id#overview)
  * [Scope](https://help.sap.com/docs/leanix/ea/discovering-ai-agents-from-microsoft-entra-id#scope)
  * [Prerequisites](https://help.sap.com/docs/leanix/ea/discovering-ai-agents-from-microsoft-entra-id#prerequisites)
  * [Step 1: Register SAP LeanIX in Microsoft Entra ID](https://help.sap.com/docs/leanix/ea/discovering-ai-agents-from-microsoft-entra-id#step-1:-register-sap-leanix-in-microsoft-entra-id)
  * [Step 2: Grant Permissions to SAP LeanIX](https://help.sap.com/docs/leanix/ea/discovering-ai-agents-from-microsoft-entra-id#step-2:-grant-permissions-to-sap-leanix)
  * [Step 3: Gather Configuration Credentials](https://help.sap.com/docs/leanix/ea/discovering-ai-agents-from-microsoft-entra-id#step-3:-gather-configuration-credentials)
  * [Step 4: Connect SAP LeanIX to Microsoft Entra ID](https://help.sap.com/docs/leanix/ea/discovering-ai-agents-from-microsoft-entra-id#step-4:-connect-sap-leanix-to-microsoft-entra-id)
  * [Linking Discovered Items to Fact Sheets](https://help.sap.com/docs/leanix/ea/discovering-ai-agents-from-microsoft-entra-id#linking-discovered-items-to-fact-sheets)
  * [Viewing Synchronization Logs](https://help.sap.com/docs/leanix/ea/discovering-ai-agents-from-microsoft-entra-id#viewing-synchronization-logs)


Learn how to integrate SAP LeanIX with Microsoft Entra ID to automate the discovery of AI agents.
